@@ -11,15 +11,6 @@ impl Coord {
     Coord { x: x, y: y }
   }
 
-  pub fn equals(a: Option<Coord>, b: Option<Coord>) -> bool {
-    match (a, b) {
-      (Some(Coord { x: x1, y: y1 }), Some(Coord { x: x2, y: y2 })) if (x1 == x2) & (y1 == y2) => {
-        true
-      }
-      _ => false,
-    }
-  }
-
   pub fn matches(&self, x: i32, y: i32) -> bool {
     self.x == x && self.y == y
   }
